@@ -55,7 +55,7 @@ function (path, SR, cutoff=1, minutes, plot = T, fulldays = T){
     if (SR != 1/60){
       data_min <- nparACT_auxfunctions1$nparACT_data_min(b, SR, data)
     }  else {
-      data_min <- data
+      data_min <- data$activity
     }
     ## ------------------------------------------
     
